@@ -1,4 +1,5 @@
 import enum
+
 from .helpers import _MyIntFlag
 
 MIN_TERMINAL_BUILD = 2375
@@ -57,6 +58,29 @@ class TIMEFRAME(enum.IntEnum):
     MN1 = 1 | 0xC000
 
 
+MINUTES_TO_TIMEFRAME = {
+    1            : TIMEFRAME.M1,
+    2            : TIMEFRAME.M2,
+    3            : TIMEFRAME.M3,
+    4            : TIMEFRAME.M4,
+    5            : TIMEFRAME.M5,
+    6            : TIMEFRAME.M6,
+    10           : TIMEFRAME.M10,
+    12           : TIMEFRAME.M12,
+    15           : TIMEFRAME.M15,
+    20           : TIMEFRAME.M20,
+    30           : TIMEFRAME.M30,
+    (1 * 60)     : TIMEFRAME.H1,
+    (2 * 60)     : TIMEFRAME.H2,
+    (3 * 60)     : TIMEFRAME.H3,
+    (6 * 60)     : TIMEFRAME.H6,
+    (8 * 60)     : TIMEFRAME.H8,
+    (12 * 60)    : TIMEFRAME.H12,
+    (24 * 60)    : TIMEFRAME.D1,
+    (7 * 24 * 60): TIMEFRAME.W1,
+    43200        : TIMEFRAME.MN1,
+}
+
 # tick copy flags
 COPY_TICKS_ALL = -1
 COPY_TICKS_INFO = 1
@@ -613,6 +637,7 @@ RES_E_INTERNAL_FAIL_TIMEOUT = -10005  # internal timeout
 RES_X_REAL_ACCOUNT_DISABLED = -200_001  # REAL ACCOUNT TRADING HAS NOT BEEN ENABLED IN THE CONTEXT MANAGER
 RES_X_TERMINAL_VERSION_OUTDATED = -200_002  # terminal version is out of date and does not support the current feature.
 RES_X_UNKNOWN_ERROR = -200_003
+RES_X_INVALID_COMMANDLINE_ARGS = -200_004
 
 
 class ERROR_CODE(enum.IntEnum):
@@ -636,7 +661,7 @@ class ERROR_CODE(enum.IntEnum):
     REAL_ACCOUNT_DISABLED = -200_001  # REAL ACCOUNT TRADING HAS NOT BEEN ENABLED IN THE CONTEXT MANAGER
     TERMINAL_VERSION_OUTDATED = -200_002  # terminal version is out of date and does not support the current feature.
     UNKNOWN_ERROR = -200_003
-
+    INVALID_COMMANDLINE_ARGS = -200_004
 
 MQL_TRADE_REQUEST_PROPS = dict(
     action=int,
