@@ -44,6 +44,19 @@ def _context_manager_modified(f):
 mt5_account_info = _mt5.account_info
 
 
+def parse_args():
+    import sys
+    try:
+        symbol = sys.argv[1]
+        timeframe = _const.MINUTES_TO_TIMEFRAME[int(sys.argv[2])]
+        return symbol, timeframe
+    except Exception:
+        if _state.raise_on_errors:
+            raise MT5Error(_const.ERROR_CODE.INVALID_COMMANDLINE_ARGS, f"Invalid command line args {sys.argv}")
+        else:
+            return None
+
+
 @_context_manager_modified
 def account_info() -> AccountInfo:
     """Get info on the current trading account. The function returns all data that can be obtained using
@@ -727,7 +740,7 @@ def symbols_get(*,
                 regex: str = None,
                 function: Callable = None,
                 **kwargs
-                ) -> Tuple[SymbolInfo]:
+                ) -> Union[Tuple[SymbolInfo], None]:
     """Get all financial instruments from the MetaTrader 5 terminal.
         The group parameter allows sorting out symbols by name. '*' can be used at the beginning and the
         end of a string.
@@ -749,16 +762,19 @@ def symbols_get(*,
     :return: A tuple of SymbolInfo objects
     """
     symbols = mt5_symbols_get(group=group) if group else mt5_symbols_get()
-    if symbols is None and _state.raise_on_errors:
-        build = version()
-        if build and build[1] < _const.MIN_TERMINAL_BUILD:
-            raise MT5Error(_const.ERROR_CODE.TERMINAL_VERSION_OUTDATED,
-                           "The terminal build needs to be updated to support this feature.")
+    if symbols is None:
+        if _state.raise_on_errors:
+            build = version()
+            if build and build[1] < _const.MIN_TERMINAL_BUILD:
+                raise MT5Error(_const.ERROR_CODE.TERMINAL_VERSION_OUTDATED,
+                               "The terminal build needs to be updated to support this feature.")
+            else:
+                error_code, des = last_error()
+                if error_code == _const.RES_S_OK:
+                    raise MT5Error(_const.ERROR_CODE.UNKNOWN_ERROR,
+                                   "Unknown Error. Is the terminal connected?")
         else:
-            error_code, des = last_error()
-            if error_code == _const.RES_S_OK:
-                raise MT5Error(_const.ERROR_CODE.UNKNOWN_ERROR,
-                               "Unknown Error. Is the terminal connected?")
+            return None
     if regex:
         if isinstance(regex, str):
             regex = re.compile(regex)
